pub struct Age {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub value: Option<Box<FHIRDecimal>>,
pub comparator: Option<Box<QuantityComparator>>,
pub unit: Option<Box<FHIRString>>,
pub system: Option<Box<FHIRUri>>,
pub code: Option<Box<FHIRCode>>,
}Expand description
A duration of time during which an organism (or a process) has existed.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
value: Option<Box<FHIRDecimal>>The value of the measured amount. The value includes an implicit precision in the presentation of the value.
comparator: Option<Box<QuantityComparator>>How the value should be understood and represented - whether the actual value is greater or less than the stated value due to measurement issues; e.g. if the comparator is “<” , then the real value is < stated value.
unit: Option<Box<FHIRString>>A human-readable form of the unit.
system: Option<Box<FHIRUri>>The identification of the system that provides the coded form of the unit.
code: Option<Box<FHIRCode>>A computer processable form of the unit in some unit representation system.