pub struct Annotation {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub author: Option<AnnotationAuthorTypeChoice>,
pub time: Option<Box<FHIRDateTime>>,
pub text: Box<FHIRMarkdown>,
}Expand description
A text note which also contains information about who made the statement and when.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
The individual responsible for making the annotation.
time: Option<Box<FHIRDateTime>>Indicates when this particular annotation was made.
text: Box<FHIRMarkdown>The text of the annotation in markdown format.