pub struct Attachment {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub contentType: Option<Box<FHIRCode>>,
pub language: Option<Box<FHIRCode>>,
pub data: Option<Box<FHIRBase64Binary>>,
pub url: Option<Box<FHIRUrl>>,
pub size: Option<Box<FHIRUnsignedInt>>,
pub hash: Option<Box<FHIRBase64Binary>>,
pub title: Option<Box<FHIRString>>,
pub creation: Option<Box<FHIRDateTime>>,
}Expand description
For referring to data content defined in other formats.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
contentType: Option<Box<FHIRCode>>Identifies the type of the data in the attachment and allows a method to be chosen to interpret or render the data. Includes mime type parameters such as charset where appropriate.
language: Option<Box<FHIRCode>>The human language of the content. The value can be any valid value according to BCP 47.
data: Option<Box<FHIRBase64Binary>>The actual data of the attachment - a sequence of bytes, base64 encoded.
url: Option<Box<FHIRUrl>>A location where the data can be accessed.
size: Option<Box<FHIRUnsignedInt>>The number of bytes of data that make up this attachment (before base64 encoding, if that is done).
hash: Option<Box<FHIRBase64Binary>>The calculated hash of the data using SHA-1. Represented using base64.
title: Option<Box<FHIRString>>A label or set of text to display in place of the data.
creation: Option<Box<FHIRDateTime>>The date that the attachment was first created.