pub struct ContactDetail {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub name: Option<Box<FHIRString>>,
pub telecom: Option<Vec<Box<ContactPoint>>>,
}Expand description
Specifies contact information for a person or organization.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
name: Option<Box<FHIRString>>The name of an individual to contact.
telecom: Option<Vec<Box<ContactPoint>>>The contact details for the individual (if a name was provided) or the organization.