pub struct ContactPoint {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub system: Option<Box<ContactPointSystem>>,
pub value: Option<Box<FHIRString>>,
pub use_: Option<Box<ContactPointUse>>,
pub rank: Option<Box<FHIRPositiveInt>>,
pub period: Option<Box<Period>>,
}Expand description
Details for all kinds of technology mediated contact points for a person or organization, including telephone, email, etc.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
system: Option<Box<ContactPointSystem>>Telecommunications form for contact point - what communications system is required to make use of the contact.
value: Option<Box<FHIRString>>The actual contact point details, in a form that is meaningful to the designated communication system (i.e. phone number or email address).
use_: Option<Box<ContactPointUse>>Identifies the purpose for the contact point.
rank: Option<Box<FHIRPositiveInt>>Specifies a preferred order in which to use a set of contacts. ContactPoints with lower rank values are more preferred than those with higher rank values.
period: Option<Box<Period>>Time period when the contact point was/is in use.