pub struct Contributor {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub type_: Box<ContributorType>,
pub name: Box<FHIRString>,
pub contact: Option<Vec<Box<ContactDetail>>>,
}Expand description
A contributor to the content of a knowledge asset, including authors, editors, reviewers, and endorsers.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
type_: Box<ContributorType>The type of contributor.
name: Box<FHIRString>The name of the individual or organization responsible for the contribution.
contact: Option<Vec<Box<ContactDetail>>>Contact details to assist a user in finding and communicating with the contributor.