pub struct DosageDoseAndRate {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub type_: Option<Box<CodeableConcept>>,
pub dose: Option<DosageDoseAndRateDoseTypeChoice>,
pub rate: Option<DosageDoseAndRateRateTypeChoice>,
}Expand description
The amount of medication administered.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
type_: Option<Box<CodeableConcept>>The kind of dose or rate specified, for example, ordered or calculated.
dose: Option<DosageDoseAndRateDoseTypeChoice>Amount of medication per dose.
rate: Option<DosageDoseAndRateRateTypeChoice>Amount of medication per unit of time.