pub struct ElementDefinitionBinding {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub strength: Box<BindingStrength>,
pub description: Option<Box<FHIRString>>,
pub valueSet: Option<Box<FHIRCanonical>>,
}Expand description
Binds to a value set if this element is coded (code, Coding, CodeableConcept, Quantity), or the data types (string, uri).
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
strength: Box<BindingStrength>Indicates the degree of conformance expectations associated with this binding - that is, the degree to which the provided value set must be adhered to in the instances.
description: Option<Box<FHIRString>>Describes the intended use of this particular set of codes.
valueSet: Option<Box<FHIRCanonical>>Refers to the value set that identifies the set of codes the binding refers to.