pub struct ElementDefinitionConstraint {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub key: Box<FHIRId>,
pub requirements: Option<Box<FHIRString>>,
pub severity: Box<ConstraintSeverity>,
pub human: Box<FHIRString>,
pub expression: Option<Box<FHIRString>>,
pub xpath: Option<Box<FHIRString>>,
pub source: Option<Box<FHIRCanonical>>,
}Expand description
Formal constraints such as co-occurrence and other constraints that can be computationally evaluated within the context of the instance.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
key: Box<FHIRId>Allows identification of which elements have their cardinalities impacted by the constraint. Will not be referenced for constraints that do not affect cardinality.
requirements: Option<Box<FHIRString>>Description of why this constraint is necessary or appropriate.
severity: Box<ConstraintSeverity>Identifies the impact constraint violation has on the conformance of the instance.
human: Box<FHIRString>Text that can be used to describe the constraint in messages identifying that the constraint has been violated.
expression: Option<Box<FHIRString>>A FHIRPath expression of constraint that can be executed to see if this constraint is met.
xpath: Option<Box<FHIRString>>An XPath expression of constraint that can be executed to see if this constraint is met.
source: Option<Box<FHIRCanonical>>A reference to the original source of the constraint, for traceability purposes.