pub struct ElementDefinitionExample {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub label: Box<FHIRString>,
pub value: ElementDefinitionExampleValueTypeChoice,
}Expand description
A sample value for this element demonstrating the type of information that would typically be found in the element.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
label: Box<FHIRString>Describes the purpose of this example amoung the set of examples.
value: ElementDefinitionExampleValueTypeChoiceThe actual value for the element, which must be one of the types allowed for this element.