pub struct ElementDefinitionMapping {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub identity: Box<FHIRId>,
pub language: Option<Box<FHIRCode>>,
pub map: Box<FHIRString>,
pub comment: Option<Box<FHIRString>>,
}Expand description
Identifies a concept from an external specification that roughly corresponds to this element.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
identity: Box<FHIRId>An internal reference to the definition of a mapping.
language: Option<Box<FHIRCode>>Identifies the computable language in which mapping.map is expressed.
map: Box<FHIRString>Expresses what part of the target specification corresponds to this element.
comment: Option<Box<FHIRString>>Comments that provide information about the mapping or its use.