pub struct Extension {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub url: String,
pub value: Option<ExtensionValueTypeChoice>,
}Expand description
Optional Extension Element - found in all resources.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
url: StringSource of the definition for the extension code - a logical name or a URL.
value: Option<ExtensionValueTypeChoice>Value of extension - must be one of a constrained set of the data types (see Extensibility for a list).