pub struct FHIRDateTime {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub value: Option<DateTime>,
}Expand description
A date, date-time or partial date (e.g. just year or year + month). If hours and minutes are specified, a time zone SHALL be populated. The format is a union of the schema types gYear, gYearMonth, date and dateTime. Seconds must be provided due to schema type constraints but may be zero-filled and may be ignored. Dates SHALL be valid dates.
Fields
id: Option<String>unique id for the element within a resource (for internal references)
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
value: Option<DateTime>The actual value