pub struct FHIRString {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub value: Option<String>,
}Expand description
A sequence of Unicode characters
Fields
id: Option<String>unique id for the element within a resource (for internal references)
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the resource. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
value: Option<String>The actual value