pub struct HumanName {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub use_: Option<Box<NameUse>>,
pub text: Option<Box<FHIRString>>,
pub family: Option<Box<FHIRString>>,
pub given: Option<Vec<Box<FHIRString>>>,
pub prefix: Option<Vec<Box<FHIRString>>>,
pub suffix: Option<Vec<Box<FHIRString>>>,
pub period: Option<Box<Period>>,
}Expand description
A human’s name with the ability to identify parts and usage.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
use_: Option<Box<NameUse>>Identifies the purpose for this name.
text: Option<Box<FHIRString>>Specifies the entire name as it should be displayed e.g. on an application UI. This may be provided instead of or as well as the specific parts.
family: Option<Box<FHIRString>>The part of a name that links to the genealogy. In some cultures (e.g. Eritrea) the family name of a son is the first name of his father.
given: Option<Vec<Box<FHIRString>>>Given name.
prefix: Option<Vec<Box<FHIRString>>>Part of the name that is acquired as a title due to academic, legal, employment or nobility status, etc. and that appears at the start of the name.
suffix: Option<Vec<Box<FHIRString>>>Part of the name that is acquired as a title due to academic, legal, employment or nobility status, etc. and that appears at the end of the name.
period: Option<Box<Period>>Indicates the period of time when this name was valid for the named person.