pub struct Identifier {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub use_: Option<Box<IdentifierUse>>,
pub type_: Option<Box<CodeableConcept>>,
pub system: Option<Box<FHIRUri>>,
pub value: Option<Box<FHIRString>>,
pub period: Option<Box<Period>>,
pub assigner: Option<Box<Reference>>,
}Expand description
An identifier - identifies some entity uniquely and unambiguously. Typically this is used for business identifiers.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
use_: Option<Box<IdentifierUse>>The purpose of this identifier.
type_: Option<Box<CodeableConcept>>A coded type for the identifier that can be used to determine which identifier to use for a specific purpose.
system: Option<Box<FHIRUri>>Establishes the namespace for the value - that is, a URL that describes a set values that are unique.
value: Option<Box<FHIRString>>The portion of the identifier typically relevant to the user and which is unique within the context of the system.
period: Option<Box<Period>>Time period during which identifier is/was valid for use.
assigner: Option<Box<Reference>>Organization that issued/manages the identifier.