pub struct Narrative {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub status: Box<NarrativeStatus>,
pub div: Box<FHIRXhtml>,
}Expand description
A human-readable summary of the resource conveying the essential clinical and business information for the resource.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
status: Box<NarrativeStatus>The status of the narrative - whether it’s entirely generated (from just the defined data or the extensions too), or whether a human authored it and it may contain additional data.
div: Box<FHIRXhtml>The actual narrative content, a stripped down version of XHTML.