pub struct ParameterDefinition {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub name: Option<Box<FHIRCode>>,
pub use_: Box<OperationParameterUse>,
pub min: Option<Box<FHIRInteger>>,
pub max: Option<Box<FHIRString>>,
pub documentation: Option<Box<FHIRString>>,
pub type_: Box<AllTypes>,
pub profile: Option<Box<FHIRCanonical>>,
}Expand description
The parameters to the module. This collection specifies both the input and output parameters. Input parameters are provided by the caller as part of the $evaluate operation. Output parameters are included in the GuidanceResponse.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
name: Option<Box<FHIRCode>>The name of the parameter used to allow access to the value of the parameter in evaluation contexts.
use_: Box<OperationParameterUse>Whether the parameter is input or output for the module.
min: Option<Box<FHIRInteger>>The minimum number of times this parameter SHALL appear in the request or response.
max: Option<Box<FHIRString>>The maximum number of times this element is permitted to appear in the request or response.
documentation: Option<Box<FHIRString>>A brief discussion of what the parameter is for and how it is used by the module.
type_: Box<AllTypes>The type of the parameter.
profile: Option<Box<FHIRCanonical>>If specified, this indicates a profile that the input data must conform to, or that the output data will conform to.