pub struct Range {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub low: Option<Box<Quantity>>,
pub high: Option<Box<Quantity>>,
}Expand description
A set of ordered Quantities defined by a low and high limit.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
low: Option<Box<Quantity>>The low limit. The boundary is inclusive.
high: Option<Box<Quantity>>The high limit. The boundary is inclusive.