pub struct Ratio {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub numerator: Option<Box<Quantity>>,
pub denominator: Option<Box<Quantity>>,
}Expand description
A relationship of two Quantity values - expressed as a numerator and a denominator.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
numerator: Option<Box<Quantity>>The value of the numerator.
denominator: Option<Box<Quantity>>The value of the denominator.