pub struct RelatedArtifact {
pub id: Option<String>,
pub extension: Option<Vec<Box<Extension>>>,
pub type_: Box<RelatedArtifactType>,
pub label: Option<Box<FHIRString>>,
pub display: Option<Box<FHIRString>>,
pub citation: Option<Box<FHIRMarkdown>>,
pub url: Option<Box<FHIRUrl>>,
pub document: Option<Box<Attachment>>,
pub resource: Option<Box<FHIRCanonical>>,
}Expand description
Related artifacts such as additional documentation, justification, or bibliographic references.
Fields
id: Option<String>Unique id for the element within a resource (for internal references). This may be any string value that does not contain spaces.
extension: Option<Vec<Box<Extension>>>May be used to represent additional information that is not part of the basic definition of the element. To make the use of extensions safe and manageable, there is a strict set of governance applied to the definition and use of extensions. Though any implementer can define an extension, there is a set of requirements that SHALL be met as part of the definition of the extension.
type_: Box<RelatedArtifactType>The type of relationship to the related artifact.
label: Option<Box<FHIRString>>A short label that can be used to reference the citation from elsewhere in the containing artifact, such as a footnote index.
display: Option<Box<FHIRString>>A brief description of the document or knowledge resource being referenced, suitable for display to a consumer.
citation: Option<Box<FHIRMarkdown>>A bibliographic citation for the related artifact. This text SHOULD be formatted according to an accepted citation format.
url: Option<Box<FHIRUrl>>A url for the artifact that can be followed to access the actual content.
document: Option<Box<Attachment>>The document being referenced, represented as an attachment. This is exclusive with the resource element.
resource: Option<Box<FHIRCanonical>>The related resource, such as a library, value set, profile, or other knowledge resource.